@@ -1,19 +1,21 @@
 #
-# $Id: Metabrik.pm,v 54787ab9963e 2016/02/18 17:46:41 gomor $
+# $Id: Metabrik.pm,v d2221083a9e6 2016/04/11 17:10:51 gomor $
 #
 package Metabrik;
 use strict;
 use warnings;
 
 # Breaking.Feature.Fix
-our $VERSION = '1.21';
-our $FIX = '1';
+our $VERSION = '1.22';
+our $FIX = '0';
 
 use base qw(Class::Gomor::Hash);
 
 our @AS = qw(
    debug
    init_done
+   preinit_done
+   check_use_properties_done
    context
    global
    log
@@ -50,7 +52,7 @@ sub brik_license {
 
 sub brik_properties {
    return {
-      revision => '$Revision: 54787ab9963e $',
+      revision => '$Revision: d2221083a9e6 $',
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
       tags => [ ],
@@ -389,6 +391,9 @@ sub brik_check_use_properties {
    my $self = shift;
    my ($use_properties) = @_;
 
+   # Do it once.
+   return 1 if $self->check_use_properties_done;
+
    my $name = $self->brik_name;
    if (! $self->can('brik_use_properties')) {
       return 1;
@@ -456,6 +461,8 @@ sub brik_check_use_properties {
       return 0;
    }
 
+   $self->check_use_properties_done(1);
+
    return 1;
 }
 
@@ -1128,6 +1135,9 @@ sub brik_has_binary {
 sub brik_preinit {
    my $self = shift;
 
+   # Do it once.
+   return $self if $self->preinit_done;
+
    my $r = $self->brik_set_default_attributes;
    if (! defined($r)) {
       return $self->_log_error("brik_preinit: brik_set_default_attributes failed");
@@ -1148,6 +1158,8 @@ sub brik_preinit {
       return $self->_log_error("brik_preinit: brik_set_use_default_attributes failed");
    }
 
+   $self->preinit_done(1);
+
    return $self;
 }
 
