@@ -1,19 +1,19 @@
 #
-# $Id: Context.pm,v e86617fa210d 2016/02/14 17:56:59 gomor $
+# $Id: Context.pm,v d73612b7334b 2016/04/15 16:10:10 gomor $
 #
 package Metabrik::Core::Context;
 use strict;
 use warnings;
 
 # Breaking.Feature.Fix
-our $VERSION = '1.21';
-our $FIX = '1';
+our $VERSION = '1.22';
+our $FIX = '0';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: e86617fa210d $',
+      revision => '$Revision: d73612b7334b $',
       tags => [ qw(main core) ],
       attributes => {
          _lp => [ qw(INTERNAL) ],
@@ -160,6 +160,9 @@ sub new_brik_run {
    my ($brik, $command, @args) = @_;
 
    my $con = Metabrik::Core::Context->new or return;
+   # We have to init because some Briks like brik::tool will search context information
+   # like available Briks, for instance.
+   $con->brik_init or return;
 
    $con->use($brik) or return;
    my $data = $con->run($brik, $command, @args) or return;
@@ -911,9 +914,14 @@ Metabrik::Core::Context - core::context Brik
 
 =head1 SYNOPSIS
 
+   # From a Perl program
    use Metabrik::Core::Context;   
 
-   my $CON = Metabrik::Core::Context->new or die("core::context");
+   my $con = Metabrik::Core::Context->new or die("core::context");
+
+   # Or from a shell, to call a Command with a one-liner
+   perl -MMetabrik::Core::Context -e 'Metabrik::Core::Context->new_brik_run( \
+      "brik::tool", "install", "lookup::iplocation")'
 
 =head1 DESCRIPTION
 
